/**
 * 判断v是否定义（非undefined, null）
 * @param v 任意值
 * @returns true or false
 */
export declare function isDef<T = unknown>(v: T): v is T;
/**
 * 判断v是否未定义（undefined, null）
 * @param v 任意值
 * @returns true or false
 */
export declare function isUnDef(v: unknown): v is undefined | null;
/**
 * 判断v是不是对象
 * @param v 任意值
 * @returns true or false
 */
export declare function isObject(v: unknown): boolean;
/**
 * 判断v是不是原生对象
 * @param v 任意值
 * @returns true or false
 */
export declare function isPlainObject(v: unknown): v is object;
/**
 * 判断v是不是指定的类型，使用Object.prototype.toString
 * @param v 任意值
 * @returns true or false
 */
export declare function is(v: unknown, t: string): boolean;
/**
 * 判断v是不是日期对象，使用Object.prototype.toString
 * @param v 任意值
 * @returns true or false
 */
export declare function isDate(v: unknown): v is Date;
/**
 * 判断v是不是正则表达式对象，使用Object.prototype.toString
 * @param v 任意值
 * @returns true or false
 */
export declare function isRegExp(v: unknown): v is RegExp;
/**
 * 判断v是不是数字，
 * @param v 任意值
 * @returns true or false
 */
export declare function isNumber(v: unknown): v is number;
/**
 * 判断v是不是字符串，
 * @param v 任意值
 * @returns true or false
 */
export declare function isString(v: unknown): v is string;
/**
 * 判断v是不是函数，
 * @param v 任意值
 * @returns true or false
 */
export declare function isFunction(v: unknown): v is Function;
/**
 * 判断v是不是数组，
 * @param v 任意值
 * @returns true or false
 */
export declare function isArray(v: unknown): v is Array<any>;
/**
 * 判断v是不是布尔型，
 * @param v 任意值
 * @returns true or false
 */
export declare function isBoolean(v: unknown): v is Boolean;
/**
 * 判断v是不是null，
 * @param v 任意值
 * @returns true or false
 */
export declare function isNull(v: unknown): v is null;
/**
 * 判断a, b是不是深度相等，递归遍历所有属性
 * @param a 任意值
 * @param b 任意值
 * @returns true or false
 */
export declare function isDeepEqual(a: any, b: any): boolean;
